@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-sidebar-embed.c,v 1.13 2005/10/10 19:02:26 chpe Exp $
+ * $Id: ephy-sidebar-embed.c,v 1.15 2006/01/18 15:42:03 jframeau Exp $
  */
 
 #include "config.h"
@@ -191,7 +191,7 @@ show_context_menu (EphySidebarEmbed *sbembed,
 	gboolean can_copy, can_cut, can_paste;
 	guint button;
 
-	ephy_embed_event_get_property (event, "framed_page", &value);
+	value = ephy_embed_event_get_property (event, "framed_page");
 	framed = g_value_get_int (value);
 
 	has_background = ephy_embed_event_has_property (event, "background_image");
@@ -230,8 +230,7 @@ show_context_menu (EphySidebarEmbed *sbembed,
 	}
 	else
 	{
-		popup = framed ? "/EphySidebarFramedDocumentPopup" :
-				 "/EphySidebarDocumentPopup";
+		popup = "/EphySidebarDocumentPopup";
 	}
 
 	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
@@ -256,6 +255,9 @@ show_context_menu (EphySidebarEmbed *sbembed,
 	gtk_action_set_sensitive (action, can_paste);
 	gtk_action_set_visible (action, !hide_edit_actions || can_paste);
 
+	action = gtk_ui_manager_get_action (manager, "/EphyDocumentPopup/OpenFrameFDP");
+	gtk_action_set_visible (action, framed);
+
 	_ephy_window_set_context_event (window, event);
 
 	widget = gtk_ui_manager_get_widget (manager, popup);
@@ -300,7 +302,7 @@ save_property_url (EphyEmbed *embed,
 	const GValue *value;
 	EphyEmbedPersist *persist;
 
-	ephy_embed_event_get_property (event, property, &value);
+	value = ephy_embed_event_get_property (event, property);
 	location = g_value_get_string (value);
 
 	persist = EPHY_EMBED_PERSIST
@@ -350,7 +352,7 @@ embed_mouse_click_cb (EphyEmbed *embed,
 				|| (context & EPHY_EMBED_CONTEXT_EMAIL_LINK));
 	is_input = (context & EPHY_EMBED_CONTEXT_INPUT) != 0;
 
-	ephy_embed_event_get_property (event, "link_target", &targetValue);
+	targetValue = ephy_embed_event_get_property (event, "link_target");
 
 	/* ctrl+click or middle click opens the link in new tab */
 	if (is_link && ((is_left_click && with_control) || is_middle_click))
@@ -358,7 +360,7 @@ embed_mouse_click_cb (EphyEmbed *embed,
 		const GValue *value;
 		const char *link_address;
 
-		ephy_embed_event_get_property (event, "link", &value);
+		value = ephy_embed_event_get_property (event, "link");
 		link_address = g_value_get_string (value);
 
 		ephy_shell_new_tab (ephy_shell, sbembed->priv->window, NULL,
@@ -380,7 +382,7 @@ embed_mouse_click_cb (EphyEmbed *embed,
 		const GValue *value;
 		const char *link_address;
 
-		ephy_embed_event_get_property (event, "link", &value);
+		value = ephy_embed_event_get_property (event, "link");
 		link_address = g_value_get_string (value);
 		ephy_window_load_url (sbembed->priv->window, link_address);
 	}
