@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-prefs.h,v 1.1 2004/09/27 16:58:21 chpe Exp $
+ *  $Id: ephy-prefs.h,v 1.3 2006/03/12 14:04:11 chpe Exp $
  */
 
 #ifndef EPHY_PREFS_H
@@ -33,8 +33,10 @@ G_BEGIN_DECLS
 #define CONF_WINDOWS_SHOW_BOOKMARKS_BAR		"/apps/epiphany/general/show_bookmarks_bar"
 #define CONF_WINDOWS_SHOW_STATUSBAR		"/apps/epiphany/general/show_statusbar"
 #define CONF_INTERFACE_MIDDLE_CLICK_OPEN_URL	"/apps/epiphany/general/middle_click_open_url"
+#define CONF_INTERFACE_TOOLBAR_STYLE		"/apps/epiphany/general/toolbar_style"
 #define CONF_AUTO_DOWNLOADS			"/apps/epiphany/general/automatic_downloads"
 #define CONF_DESKTOP_IS_HOME_DIR		"/apps/nautilus/preferences/desktop_is_home_dir"
+#define CONF_NETWORK_MANAGED			"/apps/epiphany/general/managed_network"
 
 /* Directories */
 #define CONF_STATE_SAVE_DIR		"/apps/epiphany/directories/save"
@@ -55,10 +57,13 @@ G_BEGIN_DECLS
 #define CONF_LOCKDOWN_DISABLE_PRINT_SETUP	"/desktop/gnome/lockdown/disable_print_setup"
 #define CONF_LOCKDOWN_DISABLE_COMMAND_LINE	"/desktop/gnome/lockdown/disable_command_line"
 #define CONF_LOCKDOWN_DISABLE_QUIT		"/apps/epiphany/lockdown/disable_quit"
+#define CONF_LOCKDOWN_DISABLE_JAVASCRIPT_CHROME	"/apps/epiphany/lockdown/disable_javascript_chrome"
 
 /* System prefs */
 #define CONF_DESKTOP_FTP_HANDLER	"/desktop/gnome/url-handlers/ftp/command"
 #define CONF_DESKTOP_TOOLBAR_STYLE	"/desktop/gnome/interface/toolbar_style"
+#define CONF_DESKTOP_BG_PICTURE		"/desktop/gnome/background/picture_filename"
+#define CONF_DESKTOP_BG_TYPE		"/desktop/gnome/background/picture_options"
 
 G_END_DECLS
 
